---
title: Grow structured, organised, and *usable* data
format:
  seedcase-theme-html:
    toc: false
page-layout: custom
section-divs: false
sidebar: false
about:
  id: hero-heading
  template: jolla
  image: "docs/images/home.svg"
  image-title: Image from Storyset.
  image-alt: Illustration of a woman interacting with digital files and folders, with database objects on the ground in front of her.
  image-shape: rectangle
  image-width: 25em
  links:
    - text: "Learn more"
      href: "https://sprout.seedcase-project.org/docs/"
    - text: "Install Sprout"
      href: "https://sprout.seedcase-project.org/docs/guide/installation"
    - text: "Explore guide"
      href: "https://sprout.seedcase-project.org/docs/guide"
---

```{=html}
<style>
div.quarto-about-jolla {
  margin-top: 0%;
  margin-bottom: 0%;
}
</style>
```

:::: landing-page-block
::: {#hero-heading}
{{< include /docs/includes/_badges.qmd >}}
:::
::::

::::: hero-banner
:::: landing-page-block
::: hero-text
## Standardise your data and streamline its management

Sprout is a **Python package**, and the backbone of the [**Seedcase
Project**](https://seedcase-project.org), with a flexible interface
designed and built for people whose task is to build up, structure,
describe, and organise data for research projects. It is made to offer
flexibility and control over the individual steps in a data processing
and management workflow.

We built this package mainly for digitally-technical personnel, such as
data engineers or software developers. It's designed to be easily
extended and customized to fit your needs, within a framework that
ensures your data is structured, organised, and usable.
:::
::::
:::::

::: landing-page-block
## Want to contribute?

We would love your feedback or contributions! Head over to our [GitHub
repository](https://github.com/seedcase-project/seedcase-sprout) to
share your ideas or contribute code. Your input makes us better!
:::

:::: {.content-hidden when-format="pdf"}
::: landing-page-block
## Image by [Storyset](https://storyset.com/data) {.appendix}
:::
::::
